:tocdepth: 1

#######
Credits
#######
The Maastricht Diffusion Toolbox is a model recovery toolbox primarily meant for diffusion MRI analysis.
Software development by Robbert Harms, under the (Phd) supervision of Alard Roebroeck, at Maastricht University.


************
Contributors
************

* Robbert Harms
    - Lead developer
* Alard Roebroeck
    - Phd. supervision
* Francisco Fritz
    - Added Relaxometry, MPM and SSFP models
    - Quality Control on first public version
